@@ -27,7 +27,7 @@
 
 #define ARROW_CXX_COMPILER_ID "Clang"
 #define ARROW_CXX_COMPILER_VERSION "17.0.6"
-#define ARROW_CXX_COMPILER_FLAGS "-march=armv8-a -O2 -pipe -fstack-protector-strong -fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat -Werror=format-security         -fstack-clash-protection -Wp,-D_GLIBCXX_ASSERTIONS -Qunused-arguments -fcolor-diagnostics"
+#define ARROW_CXX_COMPILER_FLAGS "-march=armv8-a -O2 -pipe -fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=3 -Wformat -Werror=format-security         -fstack-clash-protection -Wp,-D_GLIBCXX_ASSERTIONS -Qunused-arguments -fcolor-diagnostics"
 
 #define ARROW_BUILD_TYPE "RELEASE"
 
